pub struct JobList {
pub jobs: Vec<Job>,
}Fields
jobs: Vec<Job>Implementations
Sourceimpl JobList
impl JobList
Sourcepub fn sorted_by_delivery_time(&self) -> Vec<Job>
pub fn sorted_by_delivery_time(&self) -> Vec<Job>
Returns the Job List sorted by delivery time of this JobList.
Sourcepub fn sorted_by_processing_time(&self) -> Vec<Job>
pub fn sorted_by_processing_time(&self) -> Vec<Job>
Returns the Job List sorted by processing time of this JobList.
Sourcepub fn sorted_by_cooldown_time(&self) -> Vec<Job>
pub fn sorted_by_cooldown_time(&self) -> Vec<Job>
Returns the Job List sorted by cooldown time of this JobList.